elementary_vectors: SageMath package to work with elementary vectors, sign vectors, oriented matroids and vectors with components in intervals
==============================================================================================================================================

Description
-----------

SageMath package to work with elementary vectors, sign vectors, oriented matroids and vectors with components in intervals

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/elementary-vectors/

